@@ -1,24 +1,24 @@
-//////////////////////////////////////////////////////////////////////////////
-//
-//    RECOMPRESSIMAGESDIALOG.CPP
-//
-//    Copyright (C) 2004 Gilles CAULIER <caulier dot gilles at free.fr>
-//
-//    This program is free software; you can redistribute it and/or modify
-//    it under the terms of the GNU General Public License as published by
-//    the Free Software Foundation; either version 2 of the License, or
-//    (at your option) any later version.
-//
-//    This program is distributed in the hope that it will be useful,
-//    but WITHOUT ANY WARRANTY; without even the implied warranty of
-//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//    GNU General Public License for more details.
-//
-//    You should have received a copy of the GNU General Public License
-//    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
-//
-//////////////////////////////////////////////////////////////////////////////
+/* ============================================================
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-10-01
+ * Description : a kipi plugin to batch process images
+ *
+ * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * This program is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU General
+ * Public License as published by the Free Software Foundation;
+ * either version 2, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * ============================================================ */
 
 // Include files for Qt
 
@@ -53,27 +53,25 @@
 namespace KIPIBatchProcessImagesPlugin
 {
 
-//////////////////////////////////// CONSTRUCTOR ////////////////////////////////////////////
-
 RecompressImagesDialog::RecompressImagesDialog( KURL::List urlList, KIPI::Interface* interface, QWidget *parent )
                       : BatchProcessImagesDialog( urlList, interface, i18n("Batch Recompress Images"), parent )
 {
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Batch recompress images"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to batch recompress images\n"
                                                      "This plugin uses the \"convert\" program from \"ImageMagick\" package."),
-                                           "(c) 2003-2004, Gilles Caulier");
+                                           "(c) 2003-2007, Gilles Caulier");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                     "caulier dot gilles at free.fr");
+                       "caulier dot gilles at gmail dot com");
 
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Batch Recompress Images Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     //---------------------------------------------
@@ -95,26 +93,16 @@ RecompressImagesDialog::RecompressImagesDialog( KURL::List urlList, KIPI::Interf
     listImageFiles();
 }
 
-
-//////////////////////////////////// DESTRUCTOR /////////////////////////////////////////////
-
 RecompressImagesDialog::~RecompressImagesDialog()
 {
     delete m_about;
 }
 
-
-//////////////////////////////////////// SLOTS //////////////////////////////////////////////
-
 void RecompressImagesDialog::slotHelp( void )
 {
-    KApplication::kApplication()->invokeHelp("recompressimages",
-                                             "kipi-plugins");
+    KApplication::kApplication()->invokeHelp("recompressimages", "kipi-plugins");
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void RecompressImagesDialog::slotOptionsClicked(void)
 {
     RecompressOptionsDialog *optionsDialog = new RecompressOptionsDialog(this);
@@ -137,9 +125,6 @@ void RecompressImagesDialog::slotOptionsClicked(void)
     delete optionsDialog;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void RecompressImagesDialog::readSettings(void)
 {
     // Read all settings from configuration file.
@@ -168,9 +153,6 @@ void RecompressImagesDialog::readSettings(void)
     delete m_config;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void RecompressImagesDialog::saveSettings(void)
 {
     // Write all settings in configuration file.
@@ -192,9 +174,6 @@ void RecompressImagesDialog::saveSettings(void)
     delete m_config;
 }
 
-
-////////////////////////////////////////////// FONCTIONS ////////////////////////////////////////////
-
 QString RecompressImagesDialog::makeProcess(KProcess* proc, BatchProcessImagesItem *item,
                                             const QString& albumDest, bool previewMode)
 {
@@ -269,9 +248,6 @@ QString RecompressImagesDialog::makeProcess(KProcess* proc, BatchProcessImagesIt
     return(extractArguments(proc));
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 bool RecompressImagesDialog::prepareStartProcess(BatchProcessImagesItem *item,
                                                  const QString& /*albumDest*/)
 {
@@ -294,4 +270,3 @@ bool RecompressImagesDialog::prepareStartProcess(BatchProcessImagesItem *item,
 }
 
 }  // NameSpace KIPIBatchProcessImagesPlugin
-
