@@ -2,7 +2,7 @@
 //
 //    KPABOUTDATA.CPP
 //
-//    Copyright (C) 2006 Angelo Naselli <anaselli at linux dot it>
+//    Copyright (C) 2006-2008 Angelo Naselli <anaselli at linux dot it>
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -66,4 +66,4 @@ namespace KIPIPlugins
     setShortDescription(KipiPluginsVersionString.ascii());
   }
 
-}
+} // namespace KIPIPlugins
