@@ -4,7 +4,7 @@
  * Date  : 2004-11-30
  * Description :
  *
- * Copyright 2004-2005 by Renchi Raju
+ * Copyright 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -45,66 +45,67 @@
 #include <krun.h>
 #include <kdebug.h>
 #include <kconfig.h>
-#include <kdeversion.h>
-#if KDE_IS_VERSION(3,2,0)
-#include <kwallet.h>
-#endif
 
 // KIPI include files
 
-#include <libkipi/version.h>
 #include <libkipi/interface.h>
 #include <libkipi/imagedialog.h>
 
 // Local includes.
 
+#include "kpaboutdata.h"
+#include "pluginsversion.h"
+#include "galleries.h"
+#include "gallerylist.h"
 #include "gallerytalker.h"
 #include "galleryitem.h"
 #include "galleryviewitem.h"
-#include "gallerylogin.h"
 #include "gallerywidget.h"
 #include "galleryalbumdialog.h"
 #include "gallerywindow.h"
+#include "gallerywindow.moc"
 
 namespace KIPIGalleryExportPlugin
 {
 
-GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent)
-    : KDialogBase(parent, 0, true, i18n( "Gallery Export" ), Help|Close, Close, false)
+GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galleries* pGalleries)
+    : KDialogBase(parent, 0, true, i18n("Gallery Export"), Help|Close, Close, false),
+      m_interface(interface),
+      mpGalleries(pGalleries)
 {
-    m_interface   = interface;
     m_uploadCount = 0;
     m_uploadTotal = 0;
-    m_wallet      = 0;
 
     // About data and help button.
 
-    KAboutData* about = new KAboutData("kipiplugins",
-                                       I18N_NOOP("Gallery Export"),
-                                       kipi_version,
-                                       I18N_NOOP("A Kipi plugin to export image collection to remote Gallery server."),
-                                       KAboutData::License_GPL,
-                                       "(c) 2004-2005, Renchi Raju",
-                                       0,
-                                       "http://extragear.kde.org/apps/kipi");
+    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Gallery Export"),
+                                           0,
+                                           KAboutData::License_GPL,
+                                           I18N_NOOP("A Kipi plugin to export image collection to remote Gallery server."),
+                                           "(c) 2003-2005, Renchi Raju");
 
-    about->addAuthor("Renchi Raju", I18N_NOOP("Author and maintainer"),
-                     "renchi at pooh dot tam dot uiuc dot edu");
+    m_about->addAuthor("Renchi Raju", I18N_NOOP("Author"),
+                       "renchi at pooh dot tam dot uiuc dot edu");
+
+    m_about->addAuthor("Colin Guthrie", I18N_NOOP("Maintainer"),
+                       "kde at colin dot guthr dot ie");
 
     m_helpButton = actionButton( Help );
-    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
+    KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Gallery Export Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
-    GalleryWidget* widget = new GalleryWidget( this );
-    setMainWidget( widget );
-    widget->setMinimumSize( 600, 400 );
+    GalleryWidget* widget = new GalleryWidget(this);
+    setMainWidget(widget);
+    widget->setMinimumSize(600, 400);
 
     m_albumView        = widget->m_albumView;
     m_photoView        = widget->m_photoView;
     m_newAlbumBtn      = widget->m_newAlbumBtn;
     m_addPhotoBtn      = widget->m_addPhotoBtn;
+    m_captTitleCheckBox = widget->m_captTitleCheckBox;
+    m_captDescrCheckBox = widget->m_captDescrCheckBox;
     m_resizeCheckBox   = widget->m_resizeCheckBox;
     m_dimensionSpinBox = widget->m_dimensionSpinBox;
 
@@ -117,27 +118,20 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent)
     m_progressDlg->setAutoReset( true );
     m_progressDlg->setAutoClose( true );
 
-    connect( m_progressDlg, SIGNAL( canceled() ),
-             SLOT( slotAddPhotoCancel() ) );
+    connect(m_progressDlg, SIGNAL(canceled()), SLOT(slotAddPhotoCancel()));
 
-    connect( m_albumView, SIGNAL( selectionChanged() ),
-             SLOT( slotAlbumSelected() ) );
-    connect( m_photoView->browserExtension(),
-             SIGNAL( openURLRequest( const KURL&,
-                                     const KParts::URLArgs& ) ),
-             SLOT( slotOpenPhoto( const KURL& ) ) );
+    connect(m_albumView, SIGNAL(selectionChanged()), SLOT(slotAlbumSelected()));
+    connect(m_photoView->browserExtension(),
+            SIGNAL(openURLRequest(const KURL&,
+                                  const KParts::URLArgs&)),
+            SLOT(slotOpenPhoto(const KURL&)));
 
-    connect( m_newAlbumBtn, SIGNAL( clicked() ),
-             SLOT( slotNewAlbum() ) );
-    connect( m_addPhotoBtn, SIGNAL( clicked() ),
-             SLOT( slotAddPhotos() ) );
+    connect(m_newAlbumBtn, SIGNAL(clicked()), SLOT(slotNewAlbum()));
+    connect(m_addPhotoBtn, SIGNAL(clicked()), SLOT( slotAddPhotos()));
 
     // read config
     KConfig config("kipirc");
-    config.setGroup("GalleryExport Settings");
-    m_url  = config.readEntry("URL");
-    m_user = config.readEntry("User");
-    GalleryTalker::setGallery2(config.readBoolEntry("Gallery2", true));
+    config.setGroup("GallerySync Settings");
 
     m_talker = new GalleryTalker( this );
     connect( m_talker, SIGNAL( signalError( const QString& ) ),
@@ -165,6 +159,17 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent)
         m_resizeCheckBox->setChecked(false);
         m_dimensionSpinBox->setEnabled(false);
     }
+
+    if (config.readBoolEntry("Set title", true))
+        m_captTitleCheckBox->setChecked(true);
+    else
+        m_captTitleCheckBox->setChecked(false);
+
+    if (config.readBoolEntry("Set description", false))
+        m_captDescrCheckBox->setChecked(true);
+    else
+        m_captDescrCheckBox->setChecked(false);
+
     m_dimensionSpinBox->setValue(config.readNumEntry("Maximum Width", 1600));
 
     QTimer::singleShot( 0, this,  SLOT( slotDoLogin() ) );
@@ -172,22 +177,17 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent)
 
 GalleryWindow::~GalleryWindow()
 {
-#if KDE_IS_VERSION(3,2,0)
-    if (m_wallet)
-        delete m_wallet;
-#endif
-
     // write config
     KConfig config("kipirc");
-    config.setGroup("GalleryExport Settings");
-    config.writeEntry("URL",  m_url);
-    config.writeEntry("User", m_user);
-    config.writeEntry("Gallery2", GalleryTalker::isGallery2());
+    config.setGroup("GallerySync Settings");
     config.writeEntry("Resize", m_resizeCheckBox->isChecked());
+    config.writeEntry("Set title", m_captTitleCheckBox->isChecked());
+    config.writeEntry("Set description", m_captDescrCheckBox->isChecked());
     config.writeEntry("Maximum Width",  m_dimensionSpinBox->value());
 
     delete m_progressDlg;
     delete m_talker;
+    delete m_about;
 }
 
 void GalleryWindow::slotHelp()
@@ -197,68 +197,44 @@ void GalleryWindow::slotHelp()
 
 void GalleryWindow::slotDoLogin()
 {
-    QString password;
+    GalleryList dlg(this, mpGalleries);
 
-#if KDE_IS_VERSION(3,2,0)
-    if (!m_wallet)
-        m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(),
-                                               winId(),
-                                               KWallet::Wallet::Synchronous );
-    if (!m_wallet)
+    if (QDialog::Accepted != dlg.exec())
     {
-        kdWarning() << "Failed to open kwallet" << endl;
-    }
-    else
-    {
-        if (!m_wallet->hasFolder("KIPIGalleryExportPlugin"))
-        {
-            if (!m_wallet->createFolder("KIPIGalleryExportPlugin"))
-                kdWarning() << "Failed to create kwallet folder" << endl;
-        }
-
-        if (!m_wallet->setFolder("KIPIGalleryExportPlugin"))
-            kdWarning() << "Failed to set kwallet folder" << endl;
-        else
-        {
-            m_wallet->readPassword("password", password);
-        }
-    }
-#endif
-
-
-    GalleryLogin dlg( this, i18n( "Login Into Remote Gallery" ),
-                      m_url, m_user, password, GalleryTalker::isGallery2() );
-    if ( dlg.exec() != QDialog::Accepted )
-    {
-        close();
-        return;
+      close();
+      return;
     }
 
-    m_user           = dlg.name();
-    GalleryTalker::setGallery2(dlg.isgGallery2Enable());
+    Gallery* p_gallery = dlg.GetGallery();
+    if (!p_gallery)
+    {
+      close();
+      return;
+    }
 
-    KURL url(dlg.url());
+    GalleryTalker::setGallery2((2 == p_gallery->version()));
+
+    KURL url(p_gallery->url());
     if (url.protocol().isEmpty())
     {
-        url.setProtocol("http");
-        url.setHost(dlg.url());
+      url.setProtocol("http");
+      url.setHost(p_gallery->url());
     }
     if (!url.url().endsWith(".php"))
     {
-        if (GalleryTalker::isGallery2())
-            url.addPath("main.php");
-        else
-            url.addPath("gallery_remote2.php");
+      if (GalleryTalker::isGallery2())
+        url.addPath("main.php");
+      else
+        url.addPath("gallery_remote2.php");
+    }
+    // If we've done something clever, save it back to the gallery.
+    if (p_gallery->url() != url.url())
+    {
+      p_gallery->setUrl(url.url());
+      mpGalleries->Save();
     }
-    m_url = url.url();
 
-    QString newPassword = dlg.password();
-#if KDE_IS_VERSION(3,2,0)
-    if (newPassword != password && m_wallet)
-        m_wallet->writePassword("password", newPassword);
-#endif
-
-    m_talker->login( url.url(), dlg.name(), newPassword );
+    m_talker->login(url.url(), p_gallery->username(), p_gallery->password());
 }
 
 void GalleryWindow::slotLoginFailed( const QString& msg )
@@ -462,7 +438,7 @@ void GalleryWindow::slotNewAlbum()
 
     // check for prohibited chars in the album name
     // \ / * ? " ' & < > | . + # ( ) or spaces
-
+    // Todo: Change this to a QRegExp check.
     QChar ch;
     bool  clean = true;
     for (uint i=0; i<name.length(); i++)
@@ -614,6 +590,8 @@ void GalleryWindow::slotAddPhotoNext()
 
     bool res = m_talker->addPhoto( m_lastSelectedAlbum, pathComments.first,
                                    pathComments.second,
+                                   m_captTitleCheckBox->isChecked(),
+                                   m_captDescrCheckBox->isChecked(),
                                    m_resizeCheckBox->isChecked(),
                                    m_dimensionSpinBox->value() );
     if (!res)
@@ -674,5 +652,3 @@ void GalleryWindow::slotAddPhotoCancel()
 
 }
 
-#include "gallerywindow.moc"
-
