@@ -6,6 +6,7 @@
  * Date        : 2003-10-14
  * Description : batch image flip
  *
+ * Copyright (C) 2004-2007 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2003-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -30,9 +31,9 @@
 // Qt includes.
 
 #include <qobject.h>
+#include <qstring.h>
 
-class QString;
-
+class KTempFile;
 class KProcess;
 
 namespace KIPIJPEGLossLessPlugin
@@ -47,7 +48,7 @@ public:
     ImageFlip();
     ~ImageFlip();
 
-    bool flip(const QString& src, FlipAction action, const QString& TmpFolder, QString& err);
+    bool flip(const QString& src, FlipAction action, QString& err);
 
 private slots:
 
@@ -56,13 +57,13 @@ private slots:
 private:
 
     bool flipJPEG(const QString& src, const QString& dest, FlipAction action, QString& err);
-    
     bool flipImageMagick(const QString& src, const QString& dest, FlipAction action, QString& err);
 
-
 private:
 
-    QString m_stdErr;
+    QString    m_stdErr;
+
+    KTempFile *m_tmpFile;
 };
 
 }  // NameSpace KIPIJPEGLossLessPlugin
