@@ -17,16 +17,16 @@
  */
 #define JPEG_INTERNALS
 
+// LibJPEG includes.
+
 extern "C"
 {
 #include "jinclude.h"
 #include "jpeglib.h"
-
-#ifdef KDE_USE_FINAL
-#include "jpegint.h"
-#include "jerror.h"
-#endif
 }
+
+// Local includes.
+
 #include "transupp.h"		/* My own external interface */
 
 namespace KIPIJPEGLossLessPlugin
