@@ -1,15 +1,17 @@
 /* ============================================================
- * Authors     : Gilles Caulier 
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
  * Date        : 2006-10-15
  * Description : IPTC categories settings page.
- * 
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,7 +34,9 @@
 #include <klocale.h>
 #include <kdialog.h>
 #include <klistbox.h>
+#include <kiconloader.h>
 #include <klineedit.h>
+#include <kactivelabel.h>
 
 // LibKExiv2 includes. 
 
@@ -108,6 +112,8 @@ IPTCCategories::IPTCCategories(QWidget* parent)
     
     d->addSubCategoryButton = new QPushButton( i18n("&Add"), parent);
     d->delSubCategoryButton = new QPushButton( i18n("&Delete"), parent);
+    d->addSubCategoryButton->setIconSet(SmallIcon("add"));
+    d->delSubCategoryButton->setIconSet(SmallIcon("remove"));
     d->delSubCategoryButton->setEnabled(false);
 
     grid->addMultiCellWidget(d->categoryCheck, 0, 0, 0, 1);
@@ -120,9 +126,15 @@ IPTCCategories::IPTCCategories(QWidget* parent)
 
     // --------------------------------------------------------
 
-    QLabel *iptcNote = new QLabel(i18n("<b>Note: IPTC text tags only support printable "
-                                       "ASCII characters set.</b>"), parent);
-    grid->addMultiCellWidget(iptcNote, 5, 5, 1, 1);
+    KActiveLabel *note = new KActiveLabel(i18n("<b>Note: "
+                 "<b><a href='http://en.wikipedia.org/wiki/IPTC'>IPTC</a></b> "
+                 "text tags only support the printable "
+                 "<b><a href='http://en.wikipedia.org/wiki/Ascii'>ASCII</a></b> "
+                 "characters set and limit strings size. "
+                 "Use contextual help for details.</b>"), parent);
+    note->setMaximumWidth(150);
+
+    grid->addMultiCellWidget(note, 5, 5, 1, 1);
     grid->setColStretch(0, 10);                     
     grid->setRowStretch(6, 10);      
                                          
