@@ -7,18 +7,18 @@
  * Description : Raw converter batch dialog
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * ============================================================ */
 
 // C Ansi includes.
@@ -32,7 +32,7 @@ extern "C"
 
 // C++ includes.
 
-#include <cstdio> 
+#include <cstdio>
 
 // Qt includes.
 
@@ -41,7 +41,6 @@ extern "C"
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qtimer.h>
-#include <qgroupbox.h>
 #include <qfileinfo.h>
 #include <qevent.h>
 #include <qpixmap.h>
@@ -67,6 +66,7 @@ extern "C"
 
 // LibKDcraw includes.
 
+#include <libkdcraw/version.h>
 #include <libkdcraw/dcrawsettingswidget.h>
 
 // Local includes.
@@ -92,33 +92,10 @@ BatchDialog::BatchDialog(QWidget* /*parent*/)
     m_thread             = 0;
     m_page = new QWidget( this );
     setMainWidget( m_page );
-    QGridLayout *mainLayout = new QGridLayout(m_page, 5, 1, 0, spacingHint());
+    QGridLayout *mainLayout = new QGridLayout(m_page, 2, 1, 0, spacingHint());
 
     //---------------------------------------------
 
-    QFrame *headerFrame = new QFrame( m_page );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Raw Images Batch Converter"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    mainLayout->addMultiCellWidget(headerFrame, 0, 0, 0, 1);
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
-    // --------------------------------------------------------------
-
     m_listView = new KListView(m_page);
     m_listView->addColumn( i18n("Thumbnail") );
     m_listView->addColumn( i18n("Raw File") );
@@ -130,45 +107,48 @@ BatchDialog::BatchDialog(QWidget* /*parent*/)
     m_listView->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     m_listView->setSelectionMode(QListView::Single);
     m_listView->setMinimumWidth(450);
-    mainLayout->addMultiCellWidget(m_listView, 1, 5, 0, 0);
 
     // ---------------------------------------------------------------
 
-    m_rawSettingsGroup    = new QGroupBox(1, Qt::Vertical, i18n("RAW Decoding Settings"), m_page);
-    m_decodingSettingsBox = new KDcrawIface::DcrawSettingsWidget(m_rawSettingsGroup, false, true, true);
+    m_decodingSettingsBox = new KDcrawIface::DcrawSettingsWidget(m_page, false, true, true);
     m_saveSettingsBox     = new SaveSettingsWidget(m_page);
 
-    mainLayout->addMultiCellWidget(m_rawSettingsGroup, 1, 1, 1, 1);
-    mainLayout->addMultiCellWidget(m_saveSettingsBox, 2, 3, 1, 1);
+#if KDCRAW_VERSION >= 0x000105
+    m_decodingSettingsBox->addItem(m_saveSettingsBox, i18n("Save settings"));
+    m_decodingSettingsBox->updateMinimumWidth();
+#else
+    m_decodingSettingsBox->insertTab(m_saveSettingsBox, i18n("Save settings"));
+#endif
 
     m_progressBar = new KProgress(m_page);
     m_progressBar->setMaximumHeight( fontMetrics().height()+2 );
-    m_progressBar->setEnabled(false);
-    mainLayout->addMultiCellWidget(m_progressBar, 4, 4, 1, 1);
+    m_progressBar->hide();
 
+    mainLayout->addMultiCellWidget(m_listView,            0, 2, 0, 0);
+    mainLayout->addMultiCellWidget(m_decodingSettingsBox, 0, 0, 1, 1);
+    mainLayout->addMultiCellWidget(m_progressBar,         1, 1, 1, 1);
     mainLayout->setColStretch(0, 10);
-    mainLayout->setRowStretch(5, 10);
+    mainLayout->setRowStretch(2, 10);
 
     // ---------------------------------------------------------------
     // About data and help button.
 
-    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("RAW Images Batch Converter"),
-                                           NULL,
+    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("RAW Image Converter"),
+                                           0,
                                            KAboutData::License_GPL,
-                                           I18N_NOOP("A Kipi plugin to convert Raw images\n"
-                                                     "Using KDcraw library"),
+                                           I18N_NOOP("A Kipi plugin to batch convert Raw images"),
                                            "(c) 2003-2005, Renchi Raju\n"
-                                           "(c) 2006-2007, Gilles Caulier");
+                                           "(c) 2006-2008, Gilles Caulier");
 
     m_about->addAuthor("Renchi Raju", I18N_NOOP("Original author"),
-                       "renchi@pooh.tam.uiuc.edu");
+                       "renchi at pooh dot tam dot uiuc dot edu");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Maintainer"),
                        "caulier dot gilles at gmail dot com");
 
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Raw Converter Handbook"),
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"),
                                  this, SLOT(slotHelp()), 0, -1, 0);
     actionButton(Help)->setPopup( helpMenu->menu() );
 
@@ -230,8 +210,11 @@ void BatchDialog::readSettings()
     KConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
-    m_decodingSettingsBox->setCameraWB(config.readBoolEntry("Use Camera WB", true));
-    m_decodingSettingsBox->setAutoColorBalance(config.readBoolEntry("Use Auto Color Balance", true));
+    m_decodingSettingsBox->setWhiteBalance((KDcrawIface::RawDecodingSettings::WhiteBalance)
+                                            config.readNumEntry("White Balance",
+                                            KDcrawIface::RawDecodingSettings::CAMERA));
+    m_decodingSettingsBox->setCustomWhiteBalance(config.readNumEntry("Custom White Balance", 6500));
+    m_decodingSettingsBox->setCustomWhiteBalanceGreen(config.readDoubleNumEntry("Custom White Balance Green", 1.0));
     m_decodingSettingsBox->setFourColor(config.readBoolEntry("Four Color RGB", false));
     m_decodingSettingsBox->setUnclipColor(config.readNumEntry("Unclip Color", 0));
     m_decodingSettingsBox->setDontStretchPixels(config.readBoolEntry("Dont Stretch Pixels", false));
@@ -239,12 +222,15 @@ void BatchDialog::readSettings()
     m_decodingSettingsBox->setBrightness(config.readDoubleNumEntry("Brightness Multiplier", 1.0));
     m_decodingSettingsBox->setUseBlackPoint(config.readBoolEntry("Use Black Point", false));
     m_decodingSettingsBox->setBlackPoint(config.readNumEntry("Black Point", 0));
+#if KDCRAW_VERSION >= 0x000105
+    m_decodingSettingsBox->setUseWhitePoint(config.readBoolEntry("Use White Point", false));
+    m_decodingSettingsBox->setWhitePoint(config.readNumEntry("White Point", 0));
+    m_decodingSettingsBox->setMedianFilterPasses(config.readNumEntry("Median Filter Passes", 0));
+#endif
     m_decodingSettingsBox->setNRThreshold(config.readNumEntry("NR Threshold", 100));
-    m_decodingSettingsBox->setUseColorMultipliers(config.readBoolEntry("Use Color Multipliers", false));
-    m_decodingSettingsBox->setcolorMultiplier1(config.readDoubleNumEntry("Color Multiplier1", 1.0));
-    m_decodingSettingsBox->setcolorMultiplier2(config.readDoubleNumEntry("Color Multiplier2", 1.0));
-    m_decodingSettingsBox->setcolorMultiplier3(config.readDoubleNumEntry("Color Multiplier3", 1.0));
-    m_decodingSettingsBox->setcolorMultiplier4(config.readDoubleNumEntry("Color Multiplier4", 1.0));
+    m_decodingSettingsBox->setUseCACorrection(config.readBoolEntry("EnableCACorrection", false));
+    m_decodingSettingsBox->setcaRedMultiplier(config.readDoubleNumEntry("caRedMultiplier", 1.0));
+    m_decodingSettingsBox->setcaBlueMultiplier(config.readDoubleNumEntry("caBlueMultiplier", 1.0));
 
     m_decodingSettingsBox->setQuality(
         (KDcrawIface::RawDecodingSettings::DecodingQuality)config.readNumEntry("Decoding Quality", 
@@ -270,8 +256,9 @@ void BatchDialog::saveSettings()
     KConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
-    config.writeEntry("Use Camera WB", m_decodingSettingsBox->useCameraWB());
-    config.writeEntry("Use Auto Color Balance", m_decodingSettingsBox->useAutoColorBalance());
+    config.writeEntry("White Balance", m_decodingSettingsBox->whiteBalance());
+    config.writeEntry("Custom White Balance", m_decodingSettingsBox->customWhiteBalance());
+    config.writeEntry("Custom White Balance Green", m_decodingSettingsBox->customWhiteBalanceGreen());
     config.writeEntry("Four Color RGB", m_decodingSettingsBox->useFourColor());
     config.writeEntry("Unclip Color", m_decodingSettingsBox->unclipColor());
     config.writeEntry("Dont Stretch Pixels", m_decodingSettingsBox->useDontStretchPixels());
@@ -279,14 +266,17 @@ void BatchDialog::saveSettings()
     config.writeEntry("Brightness Multiplier", m_decodingSettingsBox->brightness());
     config.writeEntry("Use Black Point", m_decodingSettingsBox->useBlackPoint());
     config.writeEntry("Black Point", m_decodingSettingsBox->blackPoint());
+#if KDCRAW_VERSION >= 0x000105
+    config.writeEntry("Use White Point", m_decodingSettingsBox->useWhitePoint());
+    config.writeEntry("White Point", m_decodingSettingsBox->whitePoint());
+    config.writeEntry("Median Filter Passes", m_decodingSettingsBox->medianFilterPasses());
+#endif
     config.writeEntry("NR Threshold", m_decodingSettingsBox->NRThreshold());
+    config.writeEntry("EnableCACorrection", m_decodingSettingsBox->useCACorrection());
+    config.writeEntry("caRedMultiplier", m_decodingSettingsBox->caRedMultiplier());
+    config.writeEntry("caBlueMultiplier", m_decodingSettingsBox->caBlueMultiplier());
     config.writeEntry("Decoding Quality", (int)m_decodingSettingsBox->quality());
     config.writeEntry("Output Color Space", (int)m_decodingSettingsBox->outputColorSpace());
-    config.writeEntry("Use Color Multipliers", m_decodingSettingsBox->useColorMultipliers());
-    config.writeEntry("Color Multiplier1", m_decodingSettingsBox->colorMultiplier1());
-    config.writeEntry("Color Multiplier2", m_decodingSettingsBox->colorMultiplier2());
-    config.writeEntry("Color Multiplier3", m_decodingSettingsBox->colorMultiplier3());
-    config.writeEntry("Color Multiplier4", m_decodingSettingsBox->colorMultiplier4());
 
     config.writeEntry("Output Format", (int)m_saveSettingsBox->fileFormat());
     config.writeEntry("Conflict", (int)m_saveSettingsBox->conflictRule());
@@ -326,11 +316,12 @@ void BatchDialog::slotUser1()
 
     m_progressBar->setTotalSteps(m_fileList.count());
     m_progressBar->setProgress(0);
-    m_progressBar->setEnabled(true);
+    m_progressBar->show();
 
     KDcrawIface::RawDecodingSettings rawDecodingSettings;
-    rawDecodingSettings.cameraColorBalance         = m_decodingSettingsBox->useCameraWB();
-    rawDecodingSettings.automaticColorBalance      = m_decodingSettingsBox->useAutoColorBalance();
+    rawDecodingSettings.whiteBalance               = m_decodingSettingsBox->whiteBalance();
+    rawDecodingSettings.customWhiteBalance         = m_decodingSettingsBox->customWhiteBalance();
+    rawDecodingSettings.customWhiteBalanceGreen    = m_decodingSettingsBox->customWhiteBalanceGreen();
     rawDecodingSettings.RGBInterpolate4Colors      = m_decodingSettingsBox->useFourColor();
     rawDecodingSettings.unclipColors               = m_decodingSettingsBox->unclipColor();
     rawDecodingSettings.DontStretchPixels          = m_decodingSettingsBox->useDontStretchPixels();
@@ -338,14 +329,17 @@ void BatchDialog::slotUser1()
     rawDecodingSettings.brightness                 = m_decodingSettingsBox->brightness();
     rawDecodingSettings.enableBlackPoint           = m_decodingSettingsBox->useBlackPoint();
     rawDecodingSettings.blackPoint                 = m_decodingSettingsBox->blackPoint();
+#if KDCRAW_VERSION >= 0x000105
+    rawDecodingSettings.enableWhitePoint           = m_decodingSettingsBox->useWhitePoint();
+    rawDecodingSettings.whitePoint                 = m_decodingSettingsBox->whitePoint();
+    rawDecodingSettings.medianFilterPasses         = m_decodingSettingsBox->medianFilterPasses();
+#endif
     rawDecodingSettings.NRThreshold                = m_decodingSettingsBox->NRThreshold();
+    rawDecodingSettings.enableCACorrection         = m_decodingSettingsBox->useCACorrection();
+    rawDecodingSettings.caMultiplier[0]            = m_decodingSettingsBox->caRedMultiplier();
+    rawDecodingSettings.caMultiplier[1]            = m_decodingSettingsBox->caBlueMultiplier();
     rawDecodingSettings.RAWQuality                 = m_decodingSettingsBox->quality();
     rawDecodingSettings.outputColorSpace           = m_decodingSettingsBox->outputColorSpace();
-    rawDecodingSettings.enableColorMultipliers     = m_decodingSettingsBox->useColorMultipliers();
-    rawDecodingSettings.colorBalanceMultipliers[0] = m_decodingSettingsBox->colorMultiplier1();
-    rawDecodingSettings.colorBalanceMultipliers[1] = m_decodingSettingsBox->colorMultiplier2();
-    rawDecodingSettings.colorBalanceMultipliers[2] = m_decodingSettingsBox->colorMultiplier3();
-    rawDecodingSettings.colorBalanceMultipliers[3] = m_decodingSettingsBox->colorMultiplier4();
 
     m_thread->setRawDecodingSettings(rawDecodingSettings, m_saveSettingsBox->fileFormat());
     processOne();
@@ -367,7 +361,7 @@ void BatchDialog::slotUser2()
 void BatchDialog::slotAborted()
 {
     m_progressBar->setProgress(0);
-    m_progressBar->setEnabled(false);
+    m_progressBar->hide();
 }
 
 void BatchDialog::addItems(const QStringList& itemList)
@@ -393,7 +387,7 @@ void BatchDialog::addItems(const QStringList& itemList)
     KURL::List urlList;
 
     QPixmap pix(SmallIcon( "file_broken", KIcon::SizeLarge, KIcon::DisabledState ));
-    
+
     for (QStringList::const_iterator  it = itemList.begin();
          it != itemList.end(); ++it) 
     {
@@ -437,7 +431,7 @@ void BatchDialog::slotSaveFormatChanged()
             ext = "png";
             break;
     }
-    
+
     QListViewItemIterator it( m_listView );
     while ( it.current() ) 
     {
@@ -461,7 +455,7 @@ void BatchDialog::processOne()
         slotAborted();
         return;
     }
-    
+
     QString file(m_fileList.first());
     m_fileList.pop_front();
 
@@ -476,7 +470,7 @@ void BatchDialog::busy(bool busy)
     enableButton(User2, busy);
     enableButton(Close, !busy);
 
-    m_rawSettingsGroup->setEnabled(!busy);
+    m_decodingSettingsBox->setEnabled(!busy);
     m_saveSettingsBox->setEnabled(!busy);
     m_listView->setEnabled(!busy);
 
@@ -605,7 +599,7 @@ void BatchDialog::customEvent(QCustomEvent *event)
             }
         }
     }
-    else                 
+    else
     {
         if (!d->success)        // Something is failed...
         {
@@ -665,4 +659,3 @@ void BatchDialog::customEvent(QCustomEvent *event)
 }
 
 } // NameSpace KIPIRawConverterPlugin
-
