@@ -6,8 +6,8 @@
  * Date        : 2006-12-09
  * Description : RAW decoding interface
  *
- * Copyright (C) 2006-2007 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
- * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * NOTE: Do not use kdDebug() in this implementation because 
  *       it will be multithreaded. Use qDebug() instead. 
@@ -17,12 +17,12 @@
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * ============================================================ */
 
 // C++ includes.
@@ -31,7 +31,6 @@
 #include <cstring>
 #include <iostream>
 #include <cstdio>
-#include <cstdlib>
 
 // C Ansi includes.
 
@@ -60,11 +59,6 @@ extern "C"
 
 #include <libkexiv2/kexiv2.h>
 
-// LibKDcraw includes.
-
-#include <libkdcraw/rawfiles.h>
-#include <libkdcraw/dcrawbinary.h>
-
 // Local includes.
 
 #include "pluginsversion.h"
@@ -84,7 +78,7 @@ RawDecodingIface::~RawDecodingIface()
 }
 
 QByteArray RawDecodingIface::getICCProfilFromFile(KDcrawIface::RawDecodingSettings::OutputColorSpace colorSpace)
-{    
+{
     QString filePath;
     KGlobal::dirs()->addResourceType("profiles", KGlobal::dirs()->kde_default("data") + 
                                      "kipiplugin_rawconverter/profiles");
@@ -125,7 +119,7 @@ QByteArray RawDecodingIface::getICCProfilFromFile(KDcrawIface::RawDecodingSettin
     QFile file(filePath);
     if ( !file.open(IO_ReadOnly) ) 
         return QByteArray();
-    
+
     QByteArray data(file.size());
     QDataStream stream( &file );
     stream.readRawBytes(data.data(), data.size());
@@ -184,7 +178,7 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
         sptr += 3;
     }
 
-    QImage iptcPreview   = img.scale(800, 600, QImage::ScaleMin);
+    QImage iptcPreview   = img.scale(1280, 1024, QImage::ScaleMin);
     QImage exifThumbnail = iptcPreview.scale(160, 120, QImage::ScaleMin);
 
     // -- Write image data into destination file -------------------------------
@@ -201,7 +195,15 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
     exiv2Iface.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
     exiv2Iface.setImageDimensions(QSize(width, height));
     exiv2Iface.setExifThumbnail(exifThumbnail);
-    exiv2Iface.setImagePreview(iptcPreview);
+    
+    // Update Iptc preview.
+    // NOTE: see B.K.O #130525. a JPEG segment is limited to 64K. If the IPTC byte array is
+    // bigger than 64K duing of image preview tag size, the target JPEG image will be
+    // broken. Note that IPTC image preview tag is limited to 256K!!!
+    // There is no limitation with TIFF and PNG about IPTC byte array size.                        
+    if (outputFileFormat != SaveSettingsWidget::OUTPUT_JPEG)
+        exiv2Iface.setImagePreview(iptcPreview);
+        
     exiv2Iface.setExifTagString("Exif.Image.DocumentName", fi.fileName());
 
     switch(outputFileFormat)
@@ -210,20 +212,20 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
         {
             FILE* f = 0;
             f = fopen(QFile::encodeName(destPath), "wb");
-    
+
             if (!f) 
             {
                 qDebug("Failed to open JPEG file for writing");
                 return false;
             }
-    
+
             struct jpeg_compress_struct cinfo;
             struct jpeg_error_mgr       jerr;
-    
+
             int      row_stride;
             JSAMPROW row_pointer[1];
 
-            // Init JPEG compressor.    
+            // Init JPEG compressor.
             cinfo.err = jpeg_std_error(&jerr);
             jpeg_create_compress(&cinfo);
             jpeg_stdio_dest(&cinfo, f);
@@ -243,7 +245,8 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             cinfo.comp_info[2].h_samp_factor = 1;
             cinfo.comp_info[2].v_samp_factor = 1;
 
-            jpeg_set_quality(&cinfo, 100, true);
+            // B.K.O #154273: use 99 compresion level instead 100 to reduce output JPEG file size.
+            jpeg_set_quality(&cinfo, 99, true);
             jpeg_start_compress(&cinfo, true);
 
             // Write ICC color profil.
@@ -257,7 +260,7 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
                 row_pointer[0] = (uchar*)imageData.data() + (cinfo.next_scanline * row_stride);
                 jpeg_write_scanlines(&cinfo, row_pointer, 1);
             }
-            
+
             jpeg_finish_compress(&cinfo);
             jpeg_destroy_compress(&cinfo);
             fclose(f);
@@ -270,13 +273,13 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
         {
             FILE* f = 0;
             f = fopen(QFile::encodeName(destPath), "wb");
-    
+
             if (!f) 
             {
                 qDebug("Failed to open PNG file for writing");
                 return false;
             }
-    
+
             png_color_8 sig_bit;
             png_bytep   row_ptr;
             png_structp png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
@@ -297,7 +300,7 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             {
                 png_set_iCCP(png_ptr, info_ptr, "icc", PNG_COMPRESSION_TYPE_BASE, 
                              ICCColorProfile.data(), ICCColorProfile.size());
-            }    
+            }
 
             QString libpngver(PNG_HEADER_VERSION_STRING);
             libpngver.replace('\n', ' ');
@@ -324,14 +327,14 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             png_set_shift(png_ptr, &sig_bit);
             png_set_packing(png_ptr);
             unsigned char* ptr = (unsigned char*)imageData.data();
-    
+
             for (int y = 0; !m_cancel && (y < height); y++)
             {
                 row_ptr = (png_bytep) ptr;
                 png_write_rows(png_ptr, &row_ptr, 1);
                 ptr += (width * 3);
             }
-    
+
             png_write_end(png_ptr, info_ptr);
             png_destroy_write_struct(&png_ptr, (png_infopp) & info_ptr);
             png_destroy_info_struct(png_ptr, (png_infopp) & info_ptr);
@@ -345,15 +348,15 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             unsigned char *data=0;
             int            y;
             int            w;
-            
+
             tif = TIFFOpen(QFile::encodeName(destPath), "wb");
-    
+
             if (!tif) 
             {
                 qDebug("Failed to open TIFF file for writing");
                 return false;
             }
-    
+
             TIFFSetField(tif, TIFFTAG_IMAGEWIDTH,      width);
             TIFFSetField(tif, TIFFTAG_IMAGELENGTH,     height);
             TIFFSetField(tif, TIFFTAG_ORIENTATION,     ORIENTATION_TOPLEFT);
@@ -373,10 +376,6 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             w = TIFFScanlineSize(tif);
             TIFFSetField(tif, TIFFTAG_ROWSPERSTRIP,    TIFFDefaultStripSize(tif, 0));
 
-
-            // Store Exif data.
-            // TODO
-
             // Store Iptc data.
             QByteArray ba2 = exiv2Iface.getIptc(true);
 #if defined(TIFFTAG_PHOTOSHOP)
@@ -391,20 +390,81 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             // Write ICC profil.
             if (!ICCColorProfile.isEmpty())
             {
-#if defined(TIFFTAG_ICCPROFILE)    
+#if defined(TIFFTAG_ICCPROFILE)
                 TIFFSetField(tif, TIFFTAG_ICCPROFILE, (uint32)ICCColorProfile.size(), 
                              (uchar *)ICCColorProfile.data());
-#endif      
-            }    
+#endif
+            }
+
+            // Write full image data in tiff directory IFD0
 
-            // Write image data
             for (y = 0; !m_cancel && (y < height); y++)
             {
                 data = (unsigned char*)imageData.data() + (y * width * 3);
                 TIFFWriteScanline(tif, data, y, 0);
             }
-    
+
+            TIFFWriteDirectory(tif);
+
+            // Write thumbnail in tiff directory IFD1
+
+            QImage thumb = exiv2Iface.getExifThumbnail(false);
+            if (!thumb.isNull())
+            {
+                TIFFSetField(tif, TIFFTAG_IMAGEWIDTH,      (uint32)thumb.width());
+                TIFFSetField(tif, TIFFTAG_IMAGELENGTH,     (uint32)thumb.height());
+                TIFFSetField(tif, TIFFTAG_PHOTOMETRIC,     PHOTOMETRIC_RGB);
+                TIFFSetField(tif, TIFFTAG_PLANARCONFIG,    PLANARCONFIG_CONTIG);
+                TIFFSetField(tif, TIFFTAG_ORIENTATION,     ORIENTATION_TOPLEFT);
+                TIFFSetField(tif, TIFFTAG_RESOLUTIONUNIT,  RESUNIT_NONE);
+                TIFFSetField(tif, TIFFTAG_COMPRESSION,     COMPRESSION_NONE);
+                TIFFSetField(tif, TIFFTAG_SAMPLESPERPIXEL, 3);
+                TIFFSetField(tif, TIFFTAG_BITSPERSAMPLE,   8);
+                TIFFSetField(tif, TIFFTAG_ROWSPERSTRIP,    TIFFDefaultStripSize(tif, 0));
+
+                int    i=0;
+                uint32 x, y;
+                uchar *pixelThumb;
+                uchar *dataThumb = thumb.bits();
+                uint8 *bufThumb  = (uint8 *) _TIFFmalloc(TIFFScanlineSize(tif));
+
+                if (!bufThumb)
+                {
+                    qDebug("Cannot allocate memory buffer for TIFF thumbnail.");
+                    TIFFClose(tif);
+                    return false;
+                }
+
+                for (y = 0 ; y < uint32(thumb.height()) ; y++)
+                {
+                    i = 0;
+
+                    for (x = 0 ; x < uint32(thumb.width()) ; x++)
+                    {
+                        pixelThumb = &dataThumb[((y * thumb.width()) + x) * 4];
+
+                        // This might be endian dependent 
+                        bufThumb[i++] = (uint8)pixelThumb[2];
+                        bufThumb[i++] = (uint8)pixelThumb[1];
+                        bufThumb[i++] = (uint8)pixelThumb[0];
+                    }
+
+                    if (!TIFFWriteScanline(tif, bufThumb, y, 0))
+                    {
+                        qDebug("Cannot write TIFF thumbnail to target file.");
+                        _TIFFfree(bufThumb);
+                        TIFFClose(tif);
+                        return false;
+                    }
+                }
+
+                _TIFFfree(bufThumb);
+            }
             TIFFClose(tif);
+
+            // Store metadata (Exiv2 0.18 support tiff writting mode)
+            exiv2Iface.save(destPath);
+
             break;
         }
 
@@ -416,7 +476,7 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
                 qDebug("Failed to open ppm file for writing");
                 return false;
             }
-    
+
             fprintf(f, "P6\n%d %d\n255\n", width, height);
             fwrite(imageData.data(), 1, width*height*3, f);
             fclose(f);
@@ -428,7 +488,7 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             return false;
         }
     }
-    
+
     if (m_cancel)
     {
         ::remove(QFile::encodeName(destPath));
@@ -444,43 +504,43 @@ void RawDecodingIface::writeRawProfile(png_struct *ping, png_info *ping_info, ch
                                  char *profile_data, png_uint_32 length)
 {
     png_textp      text;
-    
+
     register long  i;
-    
+
     uchar         *sp;
-    
+
     png_charp      dp;
-    
+
     png_uint_32    allocated_length, description_length;
 
     const uchar hex[16] = {'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'};
-    
+
     qDebug("Writing Raw profile: type=%s, length=%i", profile_type, (int)length);
-    
+
     text               = (png_textp) png_malloc(ping, (png_uint_32) sizeof(png_text));
     description_length = strlen((const char *) profile_type);
     allocated_length   = (png_uint_32) (length*2 + (length >> 5) + 20 + description_length);
-    
+
     text[0].text   = (png_charp) png_malloc(ping, allocated_length);
     text[0].key    = (png_charp) png_malloc(ping, (png_uint_32) 80);
     text[0].key[0] = '\0';
-    
+
     concatenateString(text[0].key, "Raw profile type ", 4096);
     concatenateString(text[0].key, (const char *) profile_type, 62);
-    
+
     sp = (uchar*)profile_data;
     dp = text[0].text;
     *dp++='\n';
-    
+
     copyString(dp, (const char *) profile_type, allocated_length);
-    
+
     dp += description_length;
     *dp++='\n';
-    
+
     formatString(dp, allocated_length-strlen(text[0].text), "%8lu ", length);
-    
+
     dp += 8;
-    
+
     for (i=0; i < (long) length; i++)
     {
         if (i%36 == 0)
@@ -506,13 +566,13 @@ void RawDecodingIface::writeRawProfile(png_struct *ping, png_info *ping_info, ch
 size_t RawDecodingIface::concatenateString(char *destination, const char *source, const size_t length)
 {
     register char       *q;
-    
+
     register const char *p;
-    
+
     register size_t      i;
-    
+
     size_t               count;
-  
+
     if ( !destination || !source || length == 0 )
         return 0;
 
@@ -540,18 +600,18 @@ size_t RawDecodingIface::concatenateString(char *destination, const char *source
     }
 
     *q='\0';
-    
+
     return(count+(p-source));
 }
 
 size_t RawDecodingIface::copyString(char *destination, const char *source, const size_t length)
 {
     register char       *q;
-    
+
     register const char *p;
-    
+
     register size_t      i;
-        
+
     if ( !destination || !source || length == 0 )
         return 0;
 
@@ -565,7 +625,7 @@ size_t RawDecodingIface::copyString(char *destination, const char *source, const
         {
             if ((*q++=(*p++)) == '\0')
                 break;
-        } 
+        }
         while (--i != 0);
     }
 
@@ -573,21 +633,22 @@ size_t RawDecodingIface::copyString(char *destination, const char *source, const
     {
         if (length != 0)
             *q='\0';
-  
-        while (*p++ != '\0') {
-            ;
+
+        do
+        {
         }
+        while (*p++ != '\0');
     }
-    
+
     return((size_t) (p-source-1));
 }
 
 long RawDecodingIface::formatString(char *string, const size_t length, const char *format,...)
 {
     long n;
-    
+
     va_list operands;
-    
+
     va_start(operands,format);
     n = (long) formatStringList(string, length, format, operands);
     va_end(operands);
@@ -597,10 +658,10 @@ long RawDecodingIface::formatString(char *string, const size_t length, const cha
 long RawDecodingIface::formatStringList(char *string, const size_t length, const char *format, va_list operands)
 {
     int n = vsnprintf(string, length, format, operands);
-    
+
     if (n < 0)
         string[length-1] = '\0';
-    
+
     return((long) n);
 }
 
