@@ -13,12 +13,12 @@
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * ============================================================ */
 
 // C Ansi includes.
@@ -62,6 +62,7 @@ extern "C"
 
 // LibKDcraw includes.
 
+#include <libkdcraw/version.h>
 #include <libkdcraw/dcrawsettingswidget.h>
 
 // Local includes.
@@ -85,7 +86,7 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/)
 {
     m_inputFile     = file;
     m_inputFileName = QFileInfo(file).fileName();
-    
+
     QWidget *page = new QWidget( this );
     setMainWidget( page );
     QGridLayout *mainLayout = new QGridLayout(page, 1, 1, 0, spacingHint());
@@ -96,7 +97,13 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/)
 
     m_decodingSettingsBox = new KDcrawIface::DcrawSettingsWidget(page, false, true, true);
     m_saveSettingsBox     = new SaveSettingsWidget(m_decodingSettingsBox);
+
+#if KDCRAW_VERSION >= 0x000105
+    m_decodingSettingsBox->addItem(m_saveSettingsBox, i18n("Save settings"));
+    m_decodingSettingsBox->updateMinimumWidth();
+#else
     m_decodingSettingsBox->insertTab(m_saveSettingsBox, i18n("Save settings"));
+#endif
 
     mainLayout->addMultiCellWidget(m_previewWidget, 0, 1, 0, 0);
     mainLayout->addMultiCellWidget(m_decodingSettingsBox, 0, 0, 1, 1);
@@ -134,7 +141,7 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/)
                               "This uses a high-quality adaptive algorithm."));
 
     setButtonTip( User3, i18n("<p>Abort the current Raw file conversion"));
-    
+
     setButtonTip( Close, i18n("<p>Exit Raw Converter"));
 
     m_blinkPreviewTimer = new QTimer(this);
@@ -145,7 +152,7 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/)
 
     connect(m_blinkPreviewTimer, SIGNAL(timeout()),
             this, SLOT(slotPreviewBlinkTimerDone()));
-    
+
     connect(m_blinkConvertTimer, SIGNAL(timeout()),
             this, SLOT(slotConvertBlinkTimerDone()));
 
@@ -204,6 +211,11 @@ void SingleDialog::readSettings()
     m_decodingSettingsBox->setBrightness(config.readDoubleNumEntry("Brightness Multiplier", 1.0));
     m_decodingSettingsBox->setUseBlackPoint(config.readBoolEntry("Use Black Point", false));
     m_decodingSettingsBox->setBlackPoint(config.readNumEntry("Black Point", 0));
+#if KDCRAW_VERSION >= 0x000105
+    m_decodingSettingsBox->setUseWhitePoint(config.readBoolEntry("Use White Point", false));
+    m_decodingSettingsBox->setWhitePoint(config.readNumEntry("White Point", 0));
+    m_decodingSettingsBox->setMedianFilterPasses(config.readNumEntry("Median Filter Passes", 0));
+#endif
     m_decodingSettingsBox->setNRThreshold(config.readNumEntry("NR Threshold", 100));
     m_decodingSettingsBox->setUseCACorrection(config.readBoolEntry("EnableCACorrection", false));
     m_decodingSettingsBox->setcaRedMultiplier(config.readDoubleNumEntry("caRedMultiplier", 1.0));
@@ -243,6 +255,11 @@ void SingleDialog::saveSettings()
     config.writeEntry("Brightness Multiplier", m_decodingSettingsBox->brightness());
     config.writeEntry("Use Black Point", m_decodingSettingsBox->useBlackPoint());
     config.writeEntry("Black Point", m_decodingSettingsBox->blackPoint());
+#if KDCRAW_VERSION >= 0x000105
+    config.writeEntry("Use White Point", m_decodingSettingsBox->useWhitePoint());
+    config.writeEntry("White Point", m_decodingSettingsBox->whitePoint());
+    config.writeEntry("Median Filter Passes", m_decodingSettingsBox->medianFilterPasses());
+#endif
     config.writeEntry("NR Threshold", m_decodingSettingsBox->NRThreshold());
     config.writeEntry("EnableCACorrection", m_decodingSettingsBox->useCACorrection());
     config.writeEntry("caRedMultiplier", m_decodingSettingsBox->caRedMultiplier());
@@ -276,13 +293,18 @@ void SingleDialog::slotUser1()
     rawDecodingSettings.brightness                 = m_decodingSettingsBox->brightness();
     rawDecodingSettings.enableBlackPoint           = m_decodingSettingsBox->useBlackPoint();
     rawDecodingSettings.blackPoint                 = m_decodingSettingsBox->blackPoint();
+#if KDCRAW_VERSION >= 0x000105
+    rawDecodingSettings.enableWhitePoint           = m_decodingSettingsBox->useWhitePoint();
+    rawDecodingSettings.whitePoint                 = m_decodingSettingsBox->whitePoint();
+    rawDecodingSettings.medianFilterPasses         = m_decodingSettingsBox->medianFilterPasses();
+#endif
     rawDecodingSettings.NRThreshold                = m_decodingSettingsBox->NRThreshold();
     rawDecodingSettings.enableCACorrection         = m_decodingSettingsBox->useCACorrection();
     rawDecodingSettings.caMultiplier[0]            = m_decodingSettingsBox->caRedMultiplier();
     rawDecodingSettings.caMultiplier[1]            = m_decodingSettingsBox->caBlueMultiplier();
     rawDecodingSettings.RAWQuality                 = m_decodingSettingsBox->quality();
     rawDecodingSettings.outputColorSpace           = m_decodingSettingsBox->outputColorSpace();
-    
+
     m_thread->setRawDecodingSettings(rawDecodingSettings, SaveSettingsWidget::OUTPUT_PPM);
     m_thread->processHalfRawFile(KURL(m_inputFile));
     if (!m_thread->running())
@@ -303,6 +325,11 @@ void SingleDialog::slotUser2()
     rawDecodingSettings.brightness                 = m_decodingSettingsBox->brightness();
     rawDecodingSettings.enableBlackPoint           = m_decodingSettingsBox->useBlackPoint();
     rawDecodingSettings.blackPoint                 = m_decodingSettingsBox->blackPoint();
+#if KDCRAW_VERSION >= 0x000105
+    rawDecodingSettings.enableWhitePoint           = m_decodingSettingsBox->useWhitePoint();
+    rawDecodingSettings.whitePoint                 = m_decodingSettingsBox->whitePoint();
+    rawDecodingSettings.medianFilterPasses         = m_decodingSettingsBox->medianFilterPasses();
+#endif
     rawDecodingSettings.NRThreshold                = m_decodingSettingsBox->NRThreshold();
     rawDecodingSettings.enableCACorrection         = m_decodingSettingsBox->useCACorrection();
     rawDecodingSettings.caMultiplier[0]            = m_decodingSettingsBox->caRedMultiplier();
@@ -330,7 +357,7 @@ void SingleDialog::slotIdentify()
 }
 
 void SingleDialog::busy(bool val)
-{   
+{
     m_decodingSettingsBox->setEnabled(!val);
     m_saveSettingsBox->setEnabled(!val);
     enableButton (User1, !val);
@@ -505,7 +532,7 @@ void SingleDialog::customEvent(QCustomEvent *event)
             }
         }
     }
-    else                 
+    else
     {
         if (!d->success)        // Something is failed...
         {
