@@ -1,25 +1,28 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
- * Date   : 2003-10-01
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-10-01
  * Description : a kipi plugin to e-mailing images
- * 
- * Copyright 2003-2005 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright 2006 by Tom Albers <tomalbers at kde.nl>
+ *
+ * Copyright (C) 2003-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006 by Tom Albers <tomalbers at kde dot nl>
+ * Copyright (C) 2006 by Michael Hoechstetter <michael dot hoechstetter at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- * 
+ * either version 2, or (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * ============================================================ */
 
-// Include files for Qt
+// Qt includes.
 
 #include <qvbox.h>
 #include <qlayout.h>
@@ -40,7 +43,7 @@
 #include <qfileinfo.h>
 #include <qpushbutton.h>
 
-// Include files for KDE
+// KDE includes.
 
 #include <klocale.h>
 #include <klineedit.h>
@@ -59,11 +62,11 @@
 #include <kpopupmenu.h>
 #include <kurlrequester.h>
 
-// Include files for KIPI
+// LibKipi includes.
 
 #include <libkipi/imagedialog.h>
 
-// Local include files
+// Local includes.
 
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
@@ -79,7 +82,7 @@ class ImageItem : public QListBoxText
 
 public:
     ImageItem(QListBox * parent, QString const & comments, KURL const & url)
-            : QListBoxText(parent), _comments(comments), _url(url)
+        : QListBoxText(parent), _comments(comments), _url(url)
     {}
 
     QString comments()                   { return _comments;                         }
@@ -153,18 +156,24 @@ SendImagesDialog::SendImagesDialog(QWidget *parent, KIPI::Interface* interface,
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Send Images"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin for emailing images"),
-                                           "(c) 2003-2005, Gilles Caulier");
+                                           "(c) 2003-2007, Gilles Caulier");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
                        "caulier dot gilles at gmail dot com");
 
+    m_about->addAuthor("Michael Hoechstetter", I18N_NOOP("Developer"),
+                       "michael dot hoechstetter at gmx dot de");
+
+    m_about->addAuthor("Tom Albers", I18N_NOOP("Developer"),
+                       "tomalbers at kde dot nl");
+
     m_helpButton        = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Send Image Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     slotMailAgentChanged(m_mailAgentName->currentItem());
@@ -185,7 +194,7 @@ void SendImagesDialog::readSettings(void)
     KConfig config("kipirc");
     config.setGroup("SendImages Settings");
 
-    QString t = config.readPathEntry("MailAgentName", "Default");
+    QString t = config.readEntry("MailAgentName", "Default");
 
     // The _old_ Kmail (mind the lowercase 'm') called the default mailer.
     // this is now renamed to 'Default'. It should not interfere with KMail, which
@@ -223,7 +232,7 @@ void SendImagesDialog::writeSettings(void)
 
     KConfig config("kipirc");
     config.setGroup("SendImages Settings");
-    config.writePathEntry("MailAgentName", m_mailAgentName->currentText());
+    config.writeEntry("MailAgentName", m_mailAgentName->currentText());
     config.writeEntry("ThunderbirdBinPath", m_ThunderbirdBinPath->url());
     config.writeEntry("AddComments", m_addComments->isChecked());
     config.writeEntry("ImagesChangeProp", m_changeImagesProp->isChecked());
@@ -249,7 +258,7 @@ void SendImagesDialog::setupImagesList(void)
 
     m_groupBoxImageList = new QGroupBox( page_setupImagesList );
     m_groupBoxImageList->setFlat(false);
-    QGridLayout* grid = new QGridLayout( m_groupBoxImageList, 2, 2 , 20, 20);
+    QGridLayout* grid   = new QGridLayout( m_groupBoxImageList, 2, 2 , 20, 20);
 
     m_ImagesFilesListBox = new ListImageItems( m_groupBoxImageList, "ListImageItems" );
     QWhatsThis::add( m_ImagesFilesListBox, i18n( "<p>This is the list of images  to email. "
@@ -258,9 +267,9 @@ void SendImagesDialog::setupImagesList(void)
     grid->addMultiCellWidget(m_ImagesFilesListBox, 0, 2, 0, 1);
 
     KButtonBox* imagesListButtonBox = new KButtonBox( m_groupBoxImageList, Vertical );
-    QPushButton* m_addImagesButton = imagesListButtonBox->addButton ( i18n( "&Add ..." ) );
+    QPushButton* m_addImagesButton  = imagesListButtonBox->addButton ( i18n( "&Add ..." ) );
     QWhatsThis::add( m_addImagesButton, i18n("<p>Add images to the list.") );
-    QPushButton* m_remImagesButton = imagesListButtonBox->addButton ( i18n( "&Remove" ));
+    QPushButton* m_remImagesButton  = imagesListButtonBox->addButton ( i18n( "&Remove" ));
     QWhatsThis::add( m_remImagesButton, i18n("<p>Remove selected images from the list.") );
     imagesListButtonBox->layout();
     grid->addMultiCellWidget(imagesListButtonBox, 0, 1, 2, 2);
@@ -366,7 +375,7 @@ void SendImagesDialog::setupEmailOptions(void)
     QLabel *m_mailAgentLabel = new QLabel( i18n("Mail agent:"), page_setupEmailOptions);
 
     m_mailAgentName = new QComboBox( false, page_setupEmailOptions );
-    m_mailAgentName->insertItem( "Default" );
+    m_mailAgentName->insertItem( i18n("Default") );
     m_mailAgentName->insertItem( "Balsa" );
     m_mailAgentName->insertItem( "Claws Mail" );
     m_mailAgentName->insertItem( "Evolution" );
@@ -377,7 +386,7 @@ void SendImagesDialog::setupEmailOptions(void)
     m_mailAgentName->insertItem( "Sylpheed" );
     m_mailAgentName->insertItem( "Sylpheed-Claws" );
     m_mailAgentName->insertItem( "Thunderbird" );
-    m_mailAgentName->setCurrentText( "Default" );
+    m_mailAgentName->setCurrentText( i18n("Default") );
     QWhatsThis::add( m_mailAgentName, i18n("<p>Select here your preferred external mail agent program."
                                            "These mail agent versions are supported:<p>"
                                            "<b>Balsa</b>: >= 2.x<p>"
@@ -414,11 +423,11 @@ void SendImagesDialog::setupEmailOptions(void)
 
     //---------------------------------------------
 
-    m_addComments = new QCheckBox( i18n("Attach a file with comments and tags"), page_setupEmailOptions);
-    QWhatsThis::add( m_addComments, i18n("<p>If you enable this option, all images comments and tags "
+    m_addComments = new QCheckBox( i18n("Attach a file with caption and tags"), page_setupEmailOptions);
+    QWhatsThis::add( m_addComments, i18n("<p>If you enable this option, all image captions and tags "
                                          "will be added as an attached file.") );
     vlay->addWidget( m_addComments );
-    m_comment2ImageName = new QCheckBox( i18n("Generate new filenames from image comments (if comment available)"), page_setupEmailOptions);
+    m_comment2ImageName = new QCheckBox( i18n("Generate new filenames from image captions (if available)"), page_setupEmailOptions);
     vlay->addWidget( m_comment2ImageName );
 
     //---------------------------------------------
@@ -611,7 +620,7 @@ void SendImagesDialog::slotImageSelected( QListBoxItem * item )
 
     if ( !pitem ) return;
 
-    m_ImageComments->setText( i18n("Comments: %1").arg(pitem->comments()) );
+    m_ImageComments->setText( i18n("Caption: %1").arg(pitem->comments()) );
     m_ImageAlbum->setText( i18n("Album: %1").arg(pitem->album()) );
     m_imageLabel->clear();
 
@@ -678,4 +687,3 @@ void SendImagesDialog::setNbItems(void)
 }
 
 }  // NameSpace KIPISendimagesPlugin
-
