@@ -1,61 +1,66 @@
 /* ============================================================
- * File  : slideshow.cpp
- * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Date  : 2003-02-16
- * Description :
  *
- * Copyright 2003 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
-
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-02-16
+ * Description : a kipi plugin to slide images.
+ *
+ * Copyright (C) 2006-2007 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
 
-#include <klocale.h>
-#include <kdeversion.h>
-#include <kglobalsettings.h>
+// C++ includes.
+
+#include <cstdlib>
+#include <cassert>
+#include <cmath>
+#include <ctime>
+
+// Qt includes.
 
 #include <qtimer.h>
+#include <qpainter.h>
 #include <qpixmap.h>
+#include <qimage.h>
 #include <qapplication.h>
 #include <qdesktopwidget.h>
 #include <qevent.h>
 #include <qcursor.h>
 #include <qfont.h>
-
-#include <kdebug.h>
+#include <qwmatrix.h>
 #include <qtextcodec.h>
 
-extern "C"
-{
-#include <stdlib.h>
-#include <assert.h>
-#include <math.h>
-#include <time.h>
-}
-
-#include "imlibiface.h"
-#include "slideshow.h"
-#include "toolbar.h"
+// KDE includes.
 
+#include <klocale.h>
+#include <kdeversion.h>
+#include <kglobalsettings.h>
 #include <kdebug.h>
+#include <kurl.h>
+
+// Local includes.
+
+#include "toolbar.h"
+#include "slideshow.h"
+#include "slideshow.moc"
 
 namespace KIPISlideShowPlugin
-{
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
+{ 
+  
 SlideShow::SlideShow(const FileList& fileList, const QStringList& commentsList, bool ImagesHasComments)
-                     : QWidget(0, 0, WStyle_StaysOnTop | WType_Popup |
-                               WX11BypassWM | WDestructiveClose)
+         : QWidget(0, 0, WStyle_StaysOnTop | WType_Popup | WX11BypassWM | WDestructiveClose)
 {
 #if KDE_IS_VERSION(3,2,0)
     QRect deskRect = KGlobalSettings::desktopGeometry(this);
@@ -82,39 +87,46 @@ SlideShow::SlideShow(const FileList& fileList, const QStringList& commentsList,
         m_toolBar->setEnabledPrev(false);
     }
     connect(m_toolBar, SIGNAL(signalPause()),
-            SLOT(slotPause()));
+            this, SLOT(slotPause()));
+
     connect(m_toolBar, SIGNAL(signalPlay()),
-            SLOT(slotPlay()));
+            this, SLOT(slotPlay()));
+
     connect(m_toolBar, SIGNAL(signalNext()),
-            SLOT(slotNext()));
+            this, SLOT(slotNext()));
+
     connect(m_toolBar, SIGNAL(signalPrev()),
-            SLOT(slotPrev()));
+            this, SLOT(slotPrev()));
+
     connect(m_toolBar, SIGNAL(signalClose()),
-            SLOT(slotClose()));
+            this, SLOT(slotClose()));
 
     // ---------------------------------------------------------------
     
-    m_imIface   = new ImlibIface(this);
-    m_currImage = 0;
-    m_fileIndex = -1; // start with -1
+    m_currImage     = 0;
+    m_fileIndex     = -1; // start with -1
     m_effect        = 0;
     m_effectRunning = false;
+    m_intArray      = 0;
+    m_endOfShow     = false;
+
     m_timer = new QTimer();
-    connect(m_timer, SIGNAL(timeout()), SLOT(slotTimeOut()));
-    m_intArray  = 0;
-    m_endOfShow = false;
+    connect(m_timer, SIGNAL(timeout()), 
+            this, SLOT(slotTimeOut()));
 
     // --------------------------------------------------
 
-    m_fileList       = fileList;
-    m_commentsList   = commentsList;
+    m_fileList          = fileList;
+    m_commentsList      = commentsList;
+    m_ImagesHasComments = ImagesHasComments; 
 
-    m_ImagesHasComments   = ImagesHasComments; 
-    
     m_config = new KConfig("kipirc");
     m_config->setGroup("SlideShow Settings");
 
     readSettings();
+    
+    m_imageLoader = new SlideShowLoader(m_fileList, m_cacheSize, width(), height(), m_fileIndex);
+    
     // --------------------------------------------------
 
     registerEffects();
@@ -143,9 +155,6 @@ SlideShow::SlideShow(const FileList& fileList, const QStringList& commentsList,
 
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 SlideShow::~SlideShow()
 {
     m_timer->stop();
@@ -161,28 +170,26 @@ SlideShow::~SlideShow()
 
     if (m_currImage)
         delete m_currImage;
-    if (m_imIface)
-        delete m_imIface;
     
-    if (m_config) {
+    if (m_imageLoader)
+        delete m_imageLoader;
+    
+    if (m_config)
         delete m_config;
-    }
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::readSettings()
 {
-    m_delay                 = m_config->readNumEntry("Delay", 1500);
-    m_printName         = m_config->readBoolEntry("Print Filename", true);
-    m_printProgress     = m_config->readBoolEntry("Print Progress Indicator", true);
-    m_printComments     = m_config->readBoolEntry("Print Comments", false);
-    m_loop                  = m_config->readBoolEntry("Loop", false);
+    m_delay            = m_config->readNumEntry("Delay", 1500);
+    m_printName        = m_config->readBoolEntry("Print Filename", true);
+    m_printProgress    = m_config->readBoolEntry("Print Progress Indicator", true);
+    m_printComments    = m_config->readBoolEntry("Print Comments", false);
+    m_loop             = m_config->readBoolEntry("Loop", false);
     
-    m_effectName           = m_config->readEntry("Effect Name", "Random");
+    m_effectName       = m_config->readEntry("Effect Name", "Random");
+
+    m_enableMouseWheel = m_config->readBoolEntry("Enable Mouse Wheel", true);
 
-    m_enableMouseWheel      = m_config->readBoolEntry("Enable Mouse Wheel", true);
- 
     // Comments tab settings
     
     m_commentsFont = new QFont();
@@ -195,15 +202,19 @@ void SlideShow::readSettings()
     m_commentsFont->setStrikeOut(m_config->readBoolEntry("Comments Font StrikeOut", false));
     m_commentsFont->setFixedPitch(m_config->readBoolEntry("Comments Font FixedPitch", false));
     
-    m_commentsFontColor     = m_config->readUnsignedNumEntry("Comments Font Color", 0xffffff);
-    m_commentsBgColor       = m_config->readUnsignedNumEntry("Comments Bg Color", 0x000000);
+    m_commentsFontColor   = m_config->readUnsignedNumEntry("Comments Font Color", 0xffffff);
+    m_commentsBgColor     = m_config->readUnsignedNumEntry("Comments Bg Color", 0x000000);
     
-    m_commentsLinesLength   = m_config->readNumEntry("Comments Lines Length", 72);
+    m_commentsLinesLength = m_config->readNumEntry("Comments Lines Length", 72);
+
+    // Advanced settings
+    bool enableCache = m_config->readBoolEntry("Enable Cache", false);
+    if (enableCache)
+        m_cacheSize  = m_config->readNumEntry("Cache Size", 1);
+    else
+        m_cacheSize = 1;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::registerEffects()
 {
     Effects.insert("None", &SlideShow::effectNone);
@@ -221,9 +232,6 @@ void SlideShow::registerEffects()
     Effects.insert("Blobs", &SlideShow::effectBlobs);
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 QStringList SlideShow::effectNames()
 {
     QStringList effects;
@@ -246,9 +254,6 @@ QStringList SlideShow::effectNames()
     return effects;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 QMap<QString,QString> SlideShow::effectNamesI18N()
 {
     QMap<QString,QString> effects;
@@ -271,9 +276,6 @@ QMap<QString,QString> SlideShow::effectNamesI18N()
     return effects;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::slotTimeOut()
 {
     if (!m_effect) return;                         // No effect -> bye !
@@ -288,7 +290,7 @@ void SlideShow::slotTimeOut()
     {
         loadNextImage();
 
-	if (!m_currImage || m_fileList.isEmpty())   // End of slideshow ?
+        if (!m_currImage || m_fileList.isEmpty())   // End of slideshow ?
         {
             showEndOfShow();
             return;
@@ -313,9 +315,6 @@ void SlideShow::slotTimeOut()
     m_timer->start(tmout, true);
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::loadNextImage()
 {
     if (m_currImage)
@@ -323,6 +322,7 @@ void SlideShow::loadNextImage()
     m_currImage = 0;
 
     m_fileIndex++;
+    m_imageLoader->next();
     int num = m_fileList.count();
     if (m_fileIndex >= num)
     {
@@ -343,14 +343,21 @@ void SlideShow::loadNextImage()
         m_toolBar->setEnabledNext(m_fileIndex < num-1);
     }
 
-    FileAnglePair fileAngle = m_fileList[m_fileIndex];
-    QString file(fileAngle.first);
-    int     angle(fileAngle.second);
+    QPixmap* oldPixmap = m_currImage;
+    QPixmap* newPixmap = new QPixmap(m_imageLoader->getCurrent());
+    
+    QPixmap pixmap(width(),height());
+    pixmap.fill(Qt::black);
+    
+    QPainter p(&pixmap);
+    p.drawPixmap((width()-newPixmap->width())/2,
+                    (height()-newPixmap->height())/2, *newPixmap,
+                    0, 0, newPixmap->width(), newPixmap->height());
+    
+    delete newPixmap;
+    m_currImage = new QPixmap(pixmap);
+    delete oldPixmap;
     
-    m_currImage = new ImImageSS(m_imIface, file, angle);
-    m_currImage->fitSize(width(), height());
-    m_currImage->render();
-
     if (m_printName)
         printFilename();
     
@@ -361,9 +368,6 @@ void SlideShow::loadNextImage()
         printComments();
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::loadPrevImage()
 {
     if (m_currImage)
@@ -371,6 +375,7 @@ void SlideShow::loadPrevImage()
     m_currImage = 0;
 
     m_fileIndex--;
+    m_imageLoader->prev();
     int num = m_fileList.count();
     if (m_fileIndex < 0)
     {
@@ -391,14 +396,21 @@ void SlideShow::loadPrevImage()
         m_toolBar->setEnabledNext(m_fileIndex < num-1);
     }
     
-    FileAnglePair fileAngle = m_fileList[m_fileIndex];
-    QString file(fileAngle.first);
-    int     angle(fileAngle.second);
+    QPixmap* oldPixmap = m_currImage;
+    QPixmap* newPixmap = new QPixmap(m_imageLoader->getCurrent());
+    
+    QPixmap pixmap(width(),height());
+    pixmap.fill(Qt::black);
+    
+    QPainter p(&pixmap);
+    p.drawPixmap((width()-newPixmap->width())/2,
+                    (height()-newPixmap->height())/2, *newPixmap,
+                    0, 0, newPixmap->width(), newPixmap->height());
+    
+    delete newPixmap;
+    m_currImage = new QPixmap(pixmap);
+    delete oldPixmap;
     
-    m_currImage = new ImImageSS(m_imIface, file, angle);
-    m_currImage->fitSize(width(), height());
-    m_currImage->render();
-
     if (m_printName)
         printFilename();
     
@@ -409,51 +421,40 @@ void SlideShow::loadPrevImage()
         printComments();
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::showCurrentImage()
 {
     if (!m_currImage)
         return;
     
-    bitBlt(this, 0, 0, m_currImage->qpixmap(),
-           0, 0, m_currImage->qpixmap()->width(),
-           m_currImage->qpixmap()->height(), Qt::CopyROP, true);
+    bitBlt(this, 0, 0, m_currImage,
+            0, 0, m_currImage->width(),
+            m_currImage->height(), Qt::CopyROP, true);
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::printFilename()
 {
     if (!m_currImage) return;
 
     QPainter p;
-    p.begin(m_currImage->qpixmap());
-
-    QString filename(m_currImage->filename());
+    p.begin(m_currImage);
 
     p.setPen(QColor("black"));
     for (int x=9; x<=11; x++)
-        for (int y=21; y>=19; y--)
-            p.drawText(x, height()-y, filename);
+        for (int y=31; y>=29; y--)
+        p.drawText(x, height()-y, m_imageLoader->currFileName());
 
     p.setPen(QColor("white"));
-    p.drawText(10, height()-20, filename);
+    p.drawText(10, height()-30, m_imageLoader->currFileName());
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::printComments()
 {
     if (!m_currImage) return;
 
     QString comments = m_commentsList[m_fileIndex];
 
-    int yPos = 20; // Text Y coordinate
-    if (m_printName) yPos = 40;
+    int yPos = 30; // Text Y coordinate
+    if (m_printName) yPos = 50;
 
     QStringList commentsByLines;
 
@@ -465,7 +466,7 @@ void SlideShow::printComments()
         bool breakLine = FALSE; // End Of Line found
         uint currIndex; //  Comments QString current index
 
-        // Check m_im_inal lines dimension
+        // Check minimal lines dimension
 
         uint commentsLinesLengthLocal = m_commentsLinesLength;
 
@@ -478,15 +479,15 @@ void SlideShow::printComments()
         breakLine = FALSE;
 
         for ( currIndex = commentsIndex; currIndex <= commentsIndex + commentsLinesLengthLocal && 
-                                         currIndex < comments.length() &&  
-                                         !breakLine; currIndex++ )
+                                        currIndex < comments.length() &&  
+                                        !breakLine; currIndex++ )
             {
                 breakLine = (comments[currIndex] == QChar('\n')) ? TRUE : FALSE;
 
                 if (breakLine)
-                  newLine.append( ' ' );
-               else
-                 newLine.append( comments[currIndex] );
+                    newLine.append( ' ' );
+                else
+                newLine.append( comments[currIndex] );
             }
 
             commentsIndex = currIndex; // The line is ended
@@ -502,7 +503,7 @@ void SlideShow::printComments()
     }
 
     QPainter p;
-    p.begin(m_currImage->qpixmap());
+    p.begin(m_currImage);
     p.setFont(*m_commentsFont);
 
     for ( int lineNumber = 0; lineNumber < (int)commentsByLines.count(); lineNumber++ ) {
@@ -511,9 +512,9 @@ void SlideShow::printComments()
 
         // coefficient 1.5 is used to maintain distance between different lines
 
-         for (int x=9; x<=11; x++)
-             for (int y = (int)(yPos + lineNumber * 1.5 * m_commentsFont->pointSize()  + 1); 
-                      y >= (int)(yPos + lineNumber* 1.5 * m_commentsFont->pointSize()  - 1); y--)
+        for (int x=9; x<=11; x++)
+            for (int y = (int)(yPos + lineNumber * 1.5 * m_commentsFont->pointSize()  + 1); 
+                        y >= (int)(yPos + lineNumber* 1.5 * m_commentsFont->pointSize()  - 1); y--)
                 p.drawText(x, height()-y, commentsByLines[lineNumber]);
 
         p.setPen(QColor(m_commentsFontColor));
@@ -522,15 +523,12 @@ void SlideShow::printComments()
     }
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::printProgress()
 {
     if (!m_currImage) return;
 
     QPainter p;
-    p.begin(m_currImage->qpixmap());
+    p.begin(m_currImage);
 
     QString progress(QString::number(m_fileIndex+1) + "/" + QString::number(m_fileList.count()));
 
@@ -545,9 +543,6 @@ void SlideShow::printProgress()
     p.drawText(width() - stringLenght - 10, 20, progress);
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 EffectMethod SlideShow::getRandomEffect()
 {
     QStringList effs = Effects.keys();
@@ -561,9 +556,6 @@ EffectMethod SlideShow::getRandomEffect()
     return Effects[key];
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::showEndOfShow()
 {
     QPainter p;
@@ -586,9 +578,6 @@ void SlideShow::showEndOfShow()
     m_toolBar->setEnabledPrev(false);
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::keyPressEvent(QKeyEvent *event)
 {
     if (!event)
@@ -597,8 +586,6 @@ void SlideShow::keyPressEvent(QKeyEvent *event)
     m_toolBar->keyPressEvent(event);
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::mousePressEvent(QMouseEvent *e)
 {
     if (m_endOfShow)
@@ -618,8 +605,6 @@ void SlideShow::mousePressEvent(QMouseEvent *e)
     }
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::mouseMoveEvent(QMouseEvent *e)
 {
     setCursor(QCursor(Qt::ArrowCursor));
@@ -664,8 +649,6 @@ void SlideShow::mouseMoveEvent(QMouseEvent *e)
     m_toolBar->show();
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::wheelEvent(QWheelEvent *e)
 {
     if (!m_enableMouseWheel) return;
@@ -689,8 +672,6 @@ void SlideShow::wheelEvent(QWheelEvent *e)
     } 
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::slotMouseMoveTimeOut()
 {
     QPoint pos(QCursor::pos());
@@ -701,9 +682,6 @@ void SlideShow::slotMouseMoveTimeOut()
     setCursor(QCursor(Qt::BlankCursor));
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectNone(bool /* aInit */)
 {
     showCurrentImage();
@@ -711,8 +689,6 @@ int SlideShow::effectNone(bool /* aInit */)
 }
 
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectChessboard(bool aInit)
 {
     int y;
@@ -744,18 +720,15 @@ int SlideShow::effectChessboard(bool aInit)
 
     for (y=0; y<m_w; y+=(m_dy<<1))
     {
-        bitBlt(this, m_ix, y+m_iy, m_currImage->qpixmap(), m_ix, y+m_iy,
-               m_dx, m_dy, CopyROP, true);
-        bitBlt(this, m_x, y+m_y, m_currImage->qpixmap(), m_x, y+m_y,
-               m_dx, m_dy, CopyROP, true);
+        bitBlt(this, m_ix, y+m_iy, m_currImage, m_ix, y+m_iy,
+                m_dx, m_dy, CopyROP, true);
+        bitBlt(this, m_x, y+m_y, m_currImage, m_x, y+m_y,
+                m_dx, m_dy, CopyROP, true);
     }
 
     return m_wait;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectMeltdown(bool aInit)
 {
     int i, x, y;
@@ -782,7 +755,7 @@ int SlideShow::effectMeltdown(bool aInit)
         done = false;
         if ((rand()&15) < 6) continue;
         bitBlt(this, x, y+m_dy, this, x, y, m_dx, m_h-y-m_dy, CopyROP, true);
-        bitBlt(this, x, y, m_currImage->qpixmap(), x, y, m_dx, m_dy, CopyROP, true);
+        bitBlt(this, x, y, m_currImage, x, y, m_dx, m_dy, CopyROP, true);
         m_intArray[i] += m_dy;
     }
 
@@ -796,9 +769,6 @@ int SlideShow::effectMeltdown(bool aInit)
     return 15;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectSweep(bool aInit)
 {
     int w, h, x, y, i;
@@ -826,7 +796,7 @@ int SlideShow::effectSweep(bool aInit)
         }
         for (w=2,i=4,x=m_x; i>0; i--, w<<=1, x-=m_dx)
         {
-            bitBlt(this, x, 0, m_currImage->qpixmap(), x, 0, w, m_h, CopyROP, true);
+            bitBlt(this, x, 0, m_currImage, x, 0, w, m_h, CopyROP, true);
         }
         m_x += m_dx;
     }
@@ -840,7 +810,7 @@ int SlideShow::effectSweep(bool aInit)
         }
         for (h=2,i=4,y=m_y; i>0; i--, h<<=1, y-=m_dy)
         {
-            bitBlt(this, 0, y, m_currImage->qpixmap(), 0, y, m_w, h, CopyROP, true);
+            bitBlt(this, 0, y, m_currImage, 0, y, m_w, h, CopyROP, true);
         }
         m_y += m_dy;
     }
@@ -848,9 +818,6 @@ int SlideShow::effectSweep(bool aInit)
     return 20;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectRandom(bool /*aInit*/)
 {
     int x, y, i, w, h, fact, sz;
@@ -865,7 +832,7 @@ int SlideShow::effectRandom(bool /*aInit*/)
     {
         x = (rand() % w) << fact;
         y = (rand() % h) << fact;
-        bitBlt(this, x, y, m_currImage->qpixmap(), x, y, sz, sz, CopyROP, true);
+        bitBlt(this, x, y, m_currImage, x, y, sz, sz, CopyROP, true);
     }
 
     showCurrentImage();
@@ -873,9 +840,6 @@ int SlideShow::effectRandom(bool /*aInit*/)
     return -1;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectGrowing(bool aInit)
 {
     if (aInit)
@@ -899,15 +863,12 @@ int SlideShow::effectGrowing(bool aInit)
         return -1;
     }
 
-    bitBlt(this, m_x, m_y, m_currImage->qpixmap(), m_x, m_y,
-           m_w - (m_x<<1), m_h - (m_y<<1), CopyROP, true);
+    bitBlt(this, m_x, m_y, m_currImage, m_x, m_y,
+            m_w - (m_x<<1), m_h - (m_y<<1), CopyROP, true);
 
     return 20;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectIncom_ingEdges(bool aInit)
 {
     int x1, y1;
@@ -940,25 +901,22 @@ int SlideShow::effectIncom_ingEdges(bool aInit)
     if (m_subType)
     {
         // moving image edges
-        bitBlt(this,  0,  0, m_currImage->qpixmap(), m_ix-m_x, m_iy-m_y, m_x, m_y, CopyROP, true);
-        bitBlt(this, x1,  0, m_currImage->qpixmap(), m_ix, m_iy-m_y, m_x, m_y, CopyROP, true);
-        bitBlt(this,  0, y1, m_currImage->qpixmap(), m_ix-m_x, m_iy, m_x, m_y, CopyROP, true);
-        bitBlt(this, x1, y1, m_currImage->qpixmap(), m_ix, m_iy, m_x, m_y, CopyROP, true);
+        bitBlt(this,  0,  0, m_currImage, m_ix-m_x, m_iy-m_y, m_x, m_y, CopyROP, true);
+        bitBlt(this, x1,  0, m_currImage, m_ix, m_iy-m_y, m_x, m_y, CopyROP, true);
+        bitBlt(this,  0, y1, m_currImage, m_ix-m_x, m_iy, m_x, m_y, CopyROP, true);
+        bitBlt(this, x1, y1, m_currImage, m_ix, m_iy, m_x, m_y, CopyROP, true);
     }
     else
     {
         // fixed image edges
-        bitBlt(this,  0,  0, m_currImage->qpixmap(),  0,  0, m_x, m_y, CopyROP, true);
-        bitBlt(this, x1,  0, m_currImage->qpixmap(), x1,  0, m_x, m_y, CopyROP, true);
-        bitBlt(this,  0, y1, m_currImage->qpixmap(),  0, y1, m_x, m_y, CopyROP, true);
-        bitBlt(this, x1, y1, m_currImage->qpixmap(), x1, y1, m_x, m_y, CopyROP, true);
+        bitBlt(this,  0,  0, m_currImage,  0,  0, m_x, m_y, CopyROP, true);
+        bitBlt(this, x1,  0, m_currImage, x1,  0, m_x, m_y, CopyROP, true);
+        bitBlt(this,  0, y1, m_currImage,  0, y1, m_x, m_y, CopyROP, true);
+        bitBlt(this, x1, y1, m_currImage, x1, y1, m_x, m_y, CopyROP, true);
     }
     return 20;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectHorizLines(bool aInit)
 {
     static int iyPos[] = { 0, 4, 2, 6, 1, 5, 3, 7, -1 };
@@ -975,7 +933,7 @@ int SlideShow::effectHorizLines(bool aInit)
 
     for (y=iyPos[m_i]; y<m_h; y+=8)
     {
-        bitBlt(this, 0, y, m_currImage->qpixmap(), 0, y, m_w, 1, CopyROP, true);
+        bitBlt(this, 0, y, m_currImage, 0, y, m_w, 1, CopyROP, true);
     }
 
     m_i++;
@@ -983,9 +941,6 @@ int SlideShow::effectHorizLines(bool aInit)
     return -1;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectVertLines(bool aInit)
 {
     static int ixPos[] = { 0, 4, 2, 6, 1, 5, 3, 7, -1 };
@@ -1002,7 +957,7 @@ int SlideShow::effectVertLines(bool aInit)
 
     for (x=ixPos[m_i]; x<m_w; x+=8)
     {
-        bitBlt(this, x, 0, m_currImage->qpixmap(), x, 0, 1, m_h, CopyROP, true);
+        bitBlt(this, x, 0, m_currImage, x, 0, 1, m_h, CopyROP, true);
     }
 
     m_i++;
@@ -1010,9 +965,6 @@ int SlideShow::effectVertLines(bool aInit)
     return -1;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectMultiCircleOut(bool aInit)
 {
     int x, y, i;
@@ -1062,9 +1014,6 @@ int SlideShow::effectMultiCircleOut(bool aInit)
     return m_wait;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectSpiralIn(bool aInit)
 {
     if (aInit)
@@ -1122,7 +1071,7 @@ int SlideShow::effectSpiralIn(bool aInit)
         m_y0 += m_iy;
     }
 
-    bitBlt(this, m_x, m_y, m_currImage->qpixmap(), m_x, m_y, m_ix, m_iy, CopyROP, true);
+    bitBlt(this, m_x, m_y, m_currImage, m_x, m_y, m_ix, m_iy, CopyROP, true);
 
     m_x += m_dx;
     m_y += m_dy;
@@ -1131,9 +1080,6 @@ int SlideShow::effectSpiralIn(bool aInit)
     return 8;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectCircleOut(bool aInit)
 {
     int x, y;
@@ -1175,8 +1121,6 @@ int SlideShow::effectCircleOut(bool aInit)
 }
 
 
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 int SlideShow::effectBlobs(bool aInit)
 {
     int r;
@@ -1207,14 +1151,10 @@ int SlideShow::effectBlobs(bool aInit)
     return 10;
 }
 
-
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void SlideShow::startPainter(Qt::PenStyle aPen)
 {
     QBrush brush;
-    brush.setPixmap(*(m_currImage->qpixmap()));
+    brush.setPixmap(*(m_currImage));
 
     if (m_painter.isActive())
         m_painter.end();
@@ -1272,5 +1212,3 @@ void SlideShow::slotClose()
 }
 
 }  // NameSpace KIPISlideShowPlugin
-
-#include "slideshow.moc"
