@@ -7,7 +7,7 @@
  * Description : a plugin to set time stamp of picture files.
  *
  * Copyright (C) 2003-2005 by Jesper Pedersen <blackie@kde.org>
- * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,6 +25,7 @@
 
 extern "C"
 {
+#include <sys/types.h>
 #include <utime.h>
 }
 
@@ -152,16 +153,16 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, QWidget* parent)
     d = new TimeAdjustDialogPrivate;
     d->interface = interface;
 
-    QVBoxLayout *vlay = new QVBoxLayout(plainPage(), 6);
+    QVBoxLayout *vlay = new QVBoxLayout(plainPage());
 
     // -- About data and help button ----------------------------------------
 
     d->about = new KIPIPlugins::KPAboutData(I18N_NOOP("Time Adjust"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin for adjusting time stamp of picture files"),
                                            "(c) 2003-2005, Jesper K. Pedersen\n"
-                                           "(c) 2006, Gilles Caulier");
+                                           "(c) 2006-2008, Gilles Caulier");
 
     d->about->addAuthor("Jesper K. Pedersen", I18N_NOOP("Author"),
                         "blackie@kde.org");
@@ -170,34 +171,11 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, QWidget* parent)
                         "caulier dot gilles at gmail dot com");
 
     QPushButton *helpButton = actionButton(Help);
-    KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
+    KHelpMenu* helpMenu     = new KHelpMenu(this, d->about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Time Adjust Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     helpButton->setPopup(helpMenu->menu());
 
-    // -- Banner ------------------------------------------------------------
-
-    QFrame *headerFrame = new QFrame(plainPage());
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout(headerFrame);
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel(headerFrame, "pixmapLabelLeft");
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Adjust Time Stamp of Picture Files"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    vlay->addWidget( headerFrame );
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
     // -- Adjustment type ------------------------------------------------------------
 
     QVGroupBox *adjGB = new QVGroupBox(i18n("Adjustment Type"), plainPage());
@@ -212,17 +190,17 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, QWidget* parent)
     d->adjustTypeGrp->setRadioButtonExclusive(true);
 
     QHBox *hbox       = new QHBox(d->adjustTypeGrp);
-    QLabel *space1     = new QLabel(hbox);
+    QLabel *space1    = new QLabel(hbox);
     space1->setFixedWidth(15);
     d->dateCreatedSel = new KDateTimeWidget(hbox);
-    QLabel *space2     = new QLabel(hbox);
+    QLabel *space2    = new QLabel(hbox);
     space2->setFixedWidth(15);
     d->todayBtn       = new QToolButton(hbox);   
     d->todayBtn->setIconSet(SmallIcon("today"));
     QToolTip::add(d->todayBtn, i18n("Reset to current date"));
     new QLabel(hbox);
     
-    d->syncEXIFDateCheck = new QCheckBox(i18n("Update Exif creation date"), d->adjustTypeGrp);
+    d->syncEXIFDateCheck = new QCheckBox(i18n("Update EXIF creation date"), d->adjustTypeGrp);
     d->syncIPTCDateCheck = new QCheckBox(i18n("Update IPTC creation date"), d->adjustTypeGrp);
 
     vlay->addWidget(adjGB);
@@ -238,7 +216,7 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, QWidget* parent)
     gridLay->setColStretch( 5, 1 );
 
     QLabel* label = new QLabel( i18n("Hours:"), grid );
-    d->hours       = new QSpinBox( 0, 1000, 1, grid );
+    d->hours      = new QSpinBox( 0, 1000, 1, grid );
     gridLay->addWidget( label, 0, 0 );
     gridLay->addWidget( d->hours, 0, 1 );
 
@@ -466,12 +444,6 @@ void TimeAdjustDialog::slotOk()
         dateTime             = updateTime(info.path(), info.time());
         info.setTime(dateTime);
 
-        // See B.K.O #138880: set the file acess and modification time.
-        struct utimbuf ut;
-        ut.modtime = dateTime.toTime_t();
-        ut.actime  = dateTime.toTime_t();
-        ::utime(QFile::encodeName(url.path()), &ut);
-
         if (d->syncEXIFDateCheck->isChecked() || d->syncIPTCDateCheck->isChecked())
         {
             bool ret = true;
@@ -486,6 +458,8 @@ void TimeAdjustDialog::slotOk()
                     {
                         ret &= exiv2Iface.setExifTagString("Exif.Image.DateTime",
                             dateTime.toString(QString("yyyy:MM:dd hh:mm:ss")).ascii());
+                        ret &= exiv2Iface.setExifTagString("Exif.Photo.DateTimeOriginal",
+                            dateTime.toString(QString("yyyy:MM:dd hh:mm:ss")).ascii());
                     }
         
                     if (d->syncIPTCDateCheck->isChecked())
@@ -514,6 +488,12 @@ void TimeAdjustDialog::slotOk()
             else 
                 updatedURLs.append(url);
         }
+
+        // See B.K.O #138880: set the file acess and modification time (after than Exiv2 play with metadata).
+        struct utimbuf ut;
+        ut.modtime = dateTime.toTime_t();
+        ut.actime  = dateTime.toTime_t();
+        ::utime(QFile::encodeName(url.path()), &ut);
     }
 
     // We use kipi interface refreshImages() method to tell to host than 
